@@ -1,17 +1,19 @@
 """JSON formatting routines."""
 
+import datetime
 from enum import Enum
 from typing import Any
 
-import flask.json
+import simplejson
 from flask import g
+from werkzeug.http import http_date
 
 from sr.comp.comp import SRComp
 from sr.comp.http.query_utils import match_json_info
 from sr.comp.match_period import Match
 
 
-class JsonEncoder(flask.json.JSONEncoder):
+class JsonEncoder(simplejson.JSONEncoder):
     """A JSON encoder that deals with various types used in SRComp."""
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -20,7 +22,7 @@ class JsonEncoder(flask.json.JSONEncoder):
         # with the 'default' method if we require. It's a bit hacky, but it
         # works.
         # In an ideal world, the types we deal with in 'default' would have
-        # approriate '_asdict' methods.
+        # appropriate '_asdict' methods.
         kwargs['namedtuple_as_object'] = False
         kwargs['tuple_as_array'] = False
         super().__init__(*args, **kwargs)
@@ -29,7 +31,11 @@ class JsonEncoder(flask.json.JSONEncoder):
         if isinstance(obj, Enum):
             return obj.value
         elif isinstance(obj, Match):
-            comp = g.comp_man.get_comp()  # type: SRComp
+            comp: SRComp = g.comp_man.get_comp()
             return match_json_info(comp, obj)
+        elif isinstance(obj, datetime.datetime):
+            return http_date(obj.utctimetuple())
+        elif isinstance(obj, datetime.date):
+            return http_date(obj.timetuple())
         else:
             return super().default(obj)
